package be.iminds.ilabt.jfed.git;

import be.iminds.ilabt.jfed.util.KeyUtil;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.security.PrivateKey;
import java.util.Collections;
import java.util.List;

/**
 * Fallback git auth preferences: authenticate everything with the same private SSH key.
 */
public class SingleUserPassGitAuthPreferences implements GitAuthPreferences {
    @Nonnull private final String username;
    @Nullable private final String password;

    public SingleUserPassGitAuthPreferences(@Nonnull String username, @Nullable String password) {
        this.username = username;
        this.password = password;
    }

    @Nonnull
    @Override
    public List<GitAuthMethod> getGitAuthMethodAvailable(String repoUrl) {
        return Collections.singletonList(GitAuthMethod.USER_PASS);
    }

    @Override
    public boolean hasAuth(String repoUrl) {
        return GitAuthPreferences.getRepoUrlGitAuthMethod(repoUrl).contains(GitAuthMethod.USER_PASS);
    }

    @Nullable
    @Override
    public GitAuth getGitAuth(String repoUrl, GitAuthMethod... allowedMethods) {
        for (GitAuthMethod allowedMethod : allowedMethods) {
            if (allowedMethod == GitAuthMethod.USER_PASS)
                return getGitAuthUserPass(repoUrl);
        }
        return null;
    }

    @Nullable
    @Override
    public GitAuthSsh getGitAuthSsh(String repoUrl) {
        return null;
    }

    @Nullable
    @Override
    public GitAuthUserPass getGitAuthUserPass(String repoUrl) {
        return new GitAuthUserPass(repoUrl, username, password);
    }
}
